/************************************************************************/
/*									*/
/*  Paste images.							*/
/*									*/
/************************************************************************/

#   include	"appFrameConfig.h"

#   include	<stddef.h>
#   include	<stdio.h>

#   include	"appImage.h"

#   include	<appDebugon.h>

#   ifdef USE_GTK

int appImgPastePixmap(		RasterImage *	abi,
				APP_WIDGET		w,
				APP_SELECTION_EVENT *	event )
    {
LDEB(1); return -1;
    }

#   endif
